/* SmartSingleWindow.cpp
   Copyright (C) 1996, Abraham Flaxman (abie@kenlaw.com)

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */

// SmartSingleWindow.cpp
//
// a window for applications who will have only
// one window.  It's just like an ordinary window
// except when it is closed it quits the app
//
// using this instead of a standard BWindow avoids
// problems related to the fact that the main menu
// of a windowless application is never shown in 1.1d7

// One day, when dr1.08 is running on my compupter,
// I want this window to have a persistant memory
// of it's location on screen, so when it is quit
// it stores it's upper-left corner, and when it
// start it goes back to that spot.

//7/97	implemented this last feature using Jon Watte's
//	libprefs -- see QuitRequested

#pragma once on
#include "SmartSingleWindow.h"

SmartSingleWindow::SmartSingleWindow(
		BRect frame,
		const char *title,
		window_type Wtype,
		ulong flags,
		ulong workspace
	) : BWindow(frame, title, Wtype, flags, workspace)
{
	strcpy(winTitle, title);
	BRect	wFrame;
	const void * data;
    ssize_t size = 0;
    uint32 type = '    ';
    
    if (gSettings.MyGetData(winTitle, data, &size, &type) || 
    			(type != B_RECT_TYPE))    
    			;
    else	{
                memcpy(&wFrame, data, size);
				MoveTo(wFrame.LeftTop()); 
	}
	
}

bool 
SmartSingleWindow::QuitRequested()
{
	Lock();
    BRect   frame = Frame();
    
    if (gSettings.SetData(winTitle, &frame, sizeof(frame), B_RECT_TYPE))
		puts("Cannot set frame");
    else if (gSettings.Save())
		puts("Cannot save settings");
    
    be_app->PostMessage(B_QUIT_REQUESTED);
	return(TRUE);
}
